# bayeso
[![Build Status](https://travis-ci.org/jungtaekkim/bayeso.svg?branch=master)](https://travis-ci.org/jungtaekkim/bayeso)
[![Coverage Status](https://coveralls.io/repos/github/jungtaekkim/bayeso/badge.svg?branch=master)](https://coveralls.io/github/jungtaekkim/bayeso?branch=master)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/bayeso/badge/?version=latest)](http://bayeso.readthedocs.io/en/latest/?badge=latest)

Simple, but essential Bayesian optimization package.

* [Online documentation](http://bayeso.readthedocs.io)

## Installation
We recommend it should be installed in `virtualenv`.

Command

```shell
$ pip install .
```
or if you would like to use development mode,

```shell
$ pip install -r requirements.txt
$ python setup.py develop
```
in the bayeso root.

If you would like to uninstall bayeso, command it.

```shell
$ pip uninstall bayeso
```

## Supported Python Version
Higher than Python 2.

## Author
* [Jungtaek Kim](http://mlg.postech.ac.kr/~jtkim/) (POSTECH)
* [Seungjin Choi](http://mlg.postech.ac.kr/~seungjin/) (POSTECH)

## Contact
* Jungtaek Kim: [jtkim@postech.ac.kr](mailto:jtkim@postech.ac.kr)

## License
[MIT License](LICENSE)
